function plotter2(p,x,y)
% PLOTTER Plot values as the calculation proceeds.
%
% Input arguments:
%    p = column vector of handles to lineseries graphics objects
%    x = independent variable (time, yr)
%    y = dependent variable (concentration, 10^(-3) mol m^(-3))
%
% Output arguments:
%    none

% Declare the following variables as persistent so that they do not change 
% values from one call to another (if they do not exist yet, they are 
% initialized to the empty matrix): 
persistent xold yold 

% Determine array sizes
[m,n] = size(y);

% Check if xold or yold has already been initialized, or if new simulation
if (isempty(xold) || isempty(yold))
    xold = x;
    yold = y;
    return
end

% Check whether the independent variable (time) increases montonically
if (xold > x)
    xold = x;
    yold = y;
    return
end

% Plot to screen (draw line segments from 'old' to 'new' values)
for i=1:n
    set(p,'XData',[xold x],'YData',[yold(i) y(i)])
end
drawnow

% Optional pause command
% pause(0.5)

% Save as 'old' values
xold = x;
yold = y;