function [xstart, xend, delx, dumpFreq, a_th, wflx1, wflx2, ...
    resf, endf, incf, frcf] = readparams(parf)
% READPARAMS Read model parameters from file. 
%
% Input arguments:
%    parf = file name for model parameters 
%
% Output arguments:
%    xstart   = time to start (a)
%    xend     = time to end (a)
%    delx     = time step (s)
%    dumpFreq = interval for writing model output to results file (a)
%    dzt0     = box thickness (m)
%    a_th     = horizontal diffusion coefficient (m^2 s^(-1))
%    wflx1    = southern box baseline freshwater flux (Sv)
%    wflx2    = northern box baseline freshwater flux (Sv)
%    resf     = file name for results
%    endf     = file name for final values
%    incf     = file name to use for inital conditions
%    frcf     = file name for freshwater forcing

fid=fopen(parf);
while 1
    tline = fgetl(fid);
    if ~ischar(tline)
        break
    end
    i1 = regexpi(tline, '=') + 1;
    i2 = size(tline, 2);
    strl = tline(1:i1-2);
    strr = tline(i1:i2);
    % Read floating-point numbers
    if strcmp(strtok(strl), 'xstart')
        xstart   = sscanf(strr, '%f', 1);
    end
    if strcmp(strtok(strl), 'xend')
        xend     = sscanf(strr, '%f', 1);
    end
    if strcmp(strtok(strl), 'delx')
        delx     = sscanf(strr, '%f', 1);
    end
    if strcmp(strtok(strl), 'dumpFreq')
        dumpFreq = sscanf(strr, '%f', 1);
    end
    if strcmp(strtok(strl), 'a_th')
        a_th     = sscanf(strr, '%f', 1);
    end
    if strcmp(strtok(strl), 'wflx1')
        wflx1    = sscanf(strr, '%f', 1);
    end
    if strcmp(strtok(strl), 'wflx2')
        wflx2    = sscanf(strr, '%f', 1);
    end
    % Read strings
    if strcmp(strtok(strl), 'resf')
        jj       = regexp(strr,char(39));
        resf     = strr(jj(1)+1:jj(2)-1);
    end
    if strcmp(strtok(strl), 'endf')
        jj       = regexp(strr,char(39));
        endf     = strr(jj(1)+1:jj(2)-1);
    end
    if strcmp(strtok(strl), 'incf')
        jj       = regexp(strr,char(39));
        incf     = strr(jj(1)+1:jj(2)-1);
    end
    if strcmp(strtok(strl), 'frcf')
        jj       = regexp(strr,char(39));
        frcf     = strr(jj(1)+1:jj(2)-1);
    end
end
fclose(fid);
