function [x, y] = stepper(p1, p2, p3, fid, delx, dely, x, y, ...
    tsfc, dwflx1, dwflx2, qflow, dumpFreq)
% STEPPER Time stepper.
% STEPPER steps solution forward in time, plots current values and writes
% them to file.
%
% Input arguments:
%    p1-p3    = column vectors of handles to lineseries graphics objects
%    fid      = file identifier
%    delx     = time step (yr)
%    dely     = increments of dependent variables (concentrations, 
%               10^(-3) mol m^(-3))
%    x        = independent variable (time, yr) at old time level
%    y        = dependent variables (concentrations, 10^(-3) mol m^(-3))
%               at old time level
%    tsfc     = surface temperature (deg C)
%    dwflx1   = southern box freshwater flux perturbation (Sv)
%    dwflx2   = northern box freshwater flux perturbation (Sv)
%    qflow    = flow strength
%    dumpFreq = interval for writing model output to results file (a)
%
% Output arguments:
%    x      = independent variable (time, yr) at new time level
%    y      = dependent variables (concentrations, 10^(-3) mol m^(-3))
%             at new time level

% Increment y and x
y = y + dely;
x = x + delx/(365.0*86400.0);

if (mod(x, dumpFreq) == 0.0)
    % Plot current values
    plotter1(p1, dwflx1, qflow/1.0E06);
    plotter2(p2, x, y);
    plotter3(p3, x, qflow/1.0E06);
    
    % Write current values to file
    printer(fid, x, y, delx/(365.0*86400.0), dwflx1, dwflx2, qflow/1.0E06);
end
