% THC_4BOX_01 Solve 4-box model of the thermohaline circulation (THC).
%
% Author:        Andre Paul
% Written:       12 June    2009
% Last updated:  29 January 2010
% 
% Execution:     thc_4box
% Dependencies:  specs.m forcing.m filer.m core.m
%
% Solves the Rahmstorf (1996)/Zickfeld et al. (2004) 4-box model.
% Based on Fortran program four-box_1.0.f90.

% Read model parameters from file (allow for overwriting default values)
[xstart, xend, delx, dumpFreq, a_th, wflx1, wflx2, ...
    resf, endf, incf, frcf] = readparams('thc_4box.in');
delx = delx*365.0*86400.0; % convert time step from years to seconds

% Specify the problem
[cp0, rho0, cairsea, s0, rhowat, alpha, beta, kflow, d_th, ...
    dzt, dareatn, dareatt, dvolt, rvolgt, tsfc, y] = specs(a_th);

% Read model forcing from file
nent = 5; % no. of rows
nvar = 3; % no. of columns
[table] = forcing(frcf, nent, nvar);

% Set up file to use for initial conditions
x = 0.0;
[x, y] = filer(incf, x, y);

% Do calculation
x = xstart;  % initial time
core(x, xend, delx, dumpFreq, cp0, rho0, cairsea, s0, rhowat, ...
    alpha, beta, kflow, d_th, dzt, dareatt, dvolt, tsfc, wflx1, wflx2, ...
    table, resf, y)
